==> qtile-0.21.0.tar.gz: qtile-0.21.0/test/widgets/docs_screenshots/ss_quickexit.py <==
# Copyright (c) 2021 elParaguayo
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import pytest

from libqtile.widget import QuickExit


@pytest.fixture
def widget():
    yield QuickExit


@pytest.mark.parametrize(
    "screenshot_manager", [{}, {"default_text": "[X]", "countdown_format": "[{}]"}], indirect=True
)
def ss_quickexit(screenshot_manager):
    screenshot_manager.take_screenshot()

    screenshot_manager.c.bar["top"].fake_button_press(0, "top", 0, 0, button=1)
    screenshot_manager.take_screenshot()

==> qtile_0.31.0.orig.tar.gz: qtile-0.31.0/test/widgets/docs_screenshots/ss_quickexit.py <==
# Copyright (c) 2021 elParaguayo
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import pytest

from libqtile.widget import QuickExit


@pytest.fixture
def widget():
    yield QuickExit


@pytest.mark.parametrize(
    "screenshot_manager", [{}, {"default_text": "[X]", "countdown_format": "[{}]"}], indirect=True
)
def ss_quickexit(screenshot_manager):
    screenshot_manager.take_screenshot()

    screenshot_manager.c.bar["top"].fake_button_press(0, 0, button=1)
    screenshot_manager.take_screenshot()
